.. image:: https://travis-ci.org/opennode/waldur-mastermind.svg?branch=develop
    :target: https://travis-ci.org/opennode/waldur-mastermind
    :alt: Build status

Waldur MasterMind
=================

Waldur MasterMind is an open-source RESTful server for multi-tenant resource management.
It provides an easy way for sharing access to external systems.
It is used as a platform for creating private and public clouds.

Additional information can be found at http://docs.waldur.com.

Development environment setup
-----------------------------

Instructions here: https://github.com/opennode/waldur-mastermind/blob/develop/docs/guide/install-from-src.rst.

Documentation
-------------

Administration and usage guides can be found at http://docs.waldur.com .

License
-------

Waldur MasterMind is released under MIT license.

Support
-------

For professional support and integration services please contact info@opennodecloud.com.
